@@ -1,4 +1,3 @@
-from website_monitor import env
 from website_monitor.streamtopic import StreamTopic
 
 
@@ -7,21 +6,14 @@ class TestStreamTopic:
         stream_topic.publish("test message 1")
         stream_topic.publish("test message 2")
 
-        with stream_topic.consume(
-            group_id=env.require_env("WM_STREAM_CONSUMER_GROUP_ID")
-        ) as records:
+        with stream_topic.consume(group_id="test-consumer") as records:
             assert records == ["test message 1", "test message 2"]
 
     def test_consumes_nothing_when_topic_is_exhausted(self, stream_topic: StreamTopic):
-        with stream_topic.consume(
-            group_id=env.require_env("WM_STREAM_CONSUMER_GROUP_ID")
-        ) as records:
+        with stream_topic.consume(group_id="test-consumer") as records:
             assert records == []
 
     def test_groups_are_isolated(self, stream_topic: StreamTopic):
-        stream_topic.exhaust(group_id="test group 1")
-        stream_topic.exhaust(group_id="test group 2")
-
         stream_topic.publish("test message 1")
         stream_topic.publish("test message 2")
 
